#include "logworker.h"
#include <iostream>
#include <unistd.h>
#include <sys/stat.h>

LogWorker::LogWorker(QObject *parent) : QObject(parent), conn(NULL)
{
}

LogWorker::~LogWorker()
{
    disconnectBackend();
}

/**
 * @brief CrazyflieWorker::connectBackend
 * Command the worker to connect to the backend
 * will set the private class struct, conn, once done.
 * The connected() signal is emitted once complete.
 */
void LogWorker::connectBackend()
{
    if (conn == NULL) {
        conn = ucart_backendConnect();
        emit (connected());
    } else {
        qInfo() << "Attempted to connect crazyflieworker when already connected!";
    }
    startReadingLogFile();
}

std::string LogWorker::getLogFile(int type) {
    struct frontend_getlogfile_data logfile;
    char fname[256];
    logfile.command = type;
    logfile.name = fname;
    if(frontend_getlogfile(conn, &logfile)) {
        return "";
    }
    std::string result(logfile.name, strlen(logfile.name));
    return result;
}

/**
 * @brief CrazyflieWorker::disconnectBackend
 * Command the worker to disconnect from the backend,
 * sets the conn struct to null and emits the
 * disconnected() signal once complete
 */
void LogWorker::disconnectBackend()
{
    if (conn) {
         ucart_backendDisconnect(conn);
         conn = NULL;
         emit (disconnected());
    }
}

void LogWorker::startReadingLogFile() {
    std::string filename = getLogFile(0);
    std::ifstream logFile;
    logFile.open(filename.c_str());
    //std::streamoff p = 0;
    std::string line;

    // while(true) {
    //     logFile.seekg(p);
    //     while(std::getline(logFile, line)) {
    //         QString result(line.c_str());
    //         qInfo() << result;
    //         if(logFile.tellg() == -1) {
    //             p = p + line.size();
    //         }
    //         else {
    //             p = logFile.tellg();
    //         }
    //     }
    //     logFile.clear();
    // }

    while(true) {
        while(std::getline(logFile, line)) {
            QString result(line.c_str());
            qInfo() << result;
        }
        if(!logFile.eof()) {
            break;
        }
        logFile.clear();
    }
}